@@ -32,8 +32,11 @@
 #include "newgamesetup.h"
 #include "krightdialog.h"
 #include "Dialogs/joingame.h"
+#if HAVE_JABBER_SUPPORT
 #include "Jabber/kmessagejabber.h"
+#endif
 #include "newplayerdata.h"
+#include "gamesequence.h"
 
 #include <QLayout>
 #include <QSpinBox>
@@ -43,7 +46,7 @@
 #include <QUuid>
 #include <QInputDialog>
 
-#include <kwidgetsaddons_version.h>
+#include <KLazyLocalizedString>
 #include <KLocalizedString>
 #include <KLineEdit>
 #include <KMessageBox>
@@ -171,7 +174,9 @@ GameAutomaton::GameAutomaton() :
   m_skinId = m_skin.registerData(dataHandler(),KGamePropertyBase::PolicyDirty,QString("m_skin"));
 //   m_currentPlayerId = m_currentPlayer.registerData(dataHandler(),KGamePropertyBase::PolicyDirty,QString("m_currentPlayer"));
 //   m_events.registerData(dataHandler(),KGamePropertyBase::PolicyDirty,QString("m_events"));
-  
+
+    setGameSequence(new GameSequence(this));
+
   // Connect the most important slot which tells us which properties are
   // changed
   connect(this,&KGame::signalPropertyChanged,
@@ -1071,7 +1076,7 @@ void GameAutomaton::createIO(KPlayer *player,KGameIO::IOMode io)
 // Note: The default behaviour as we have it here is done automatically
 //        by the lib, too. So if all players player one after the other
 //        this functions is NOT needed at all.
-KPlayer * GameAutomaton::nextPlayer(KPlayer */*last*/,bool /*exclusive*/)
+KPlayer * GameAutomaton::doNextPlayer(KPlayer */*last*/,bool /*exclusive*/)
 {
 //   qCDebug(KSIRK_LOG) << last->name();
 //   m_game->setCurrentPlayerToNext();
@@ -1212,6 +1217,7 @@ bool GameAutomaton::connectToServ()
   return status;
 }
 
+#if HAVE_JABBER_SUPPORT
 bool GameAutomaton::joinJabberGame(const QString& nick)
 {
   if (stateName() == "INIT" || (KMessageBox::warningContinueCancel(m_game,i18n("Do you really want to end your current game and join another?"),i18n( "New game confirmation" ),KGuiItem(i18nc("@action:button", "Join New Game"))) == KMessageBox::Continue))
@@ -1248,6 +1254,7 @@ bool GameAutomaton::joinJabberGame(const QString& nick)
   }
   return false;
 }
+#endif
 
 KPlayer * GameAutomaton::createPlayer(int rtti, 
                                     int /*io*/, 
@@ -1394,7 +1401,7 @@ void GameAutomaton::slotPlayerJoinedGame(KPlayer* player)
     }
     KMessageParts messageParts;
     messageParts 
-      << I18N_NOOP("%1 (%2) joined game ; waiting for %3 players to connect")
+      << kli18n("%1 (%2) joined game ; waiting for %3 players to connect").untranslatedText()
       << p-> name() << p->getNation()->name() 
       << QString::number(maxPlayers() - int(playerList()->count()));
     m_game->broadcastChangeItem(messageParts, ID_STATUS_MSG2);
@@ -1654,29 +1661,17 @@ void GameAutomaton::slotConnectionToServerBroken()
 //   m_game->haltTimer();
   if (m_state != GAME_OVER)
   {
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
     int answer = KMessageBox::questionTwoActionsCancel(m_game,
-#else
-    int answer = KMessageBox::questionYesNoCancel(m_game,
-#endif
                                                   i18n("KsirK - Lost connection to server!\nWhat do you want to do?"),
                                                   i18n("Starting a new game or exit."),
                                                   KGuiItem(i18n("New Game")),
                                                   KGuiItem(i18n("Exit")),
                                                   KGuiItem(i18n("Do nothing")));
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
     if (answer == KMessageBox::PrimaryAction)
-#else
-    if (answer == KMessageBox::Yes)
-#endif
     {
       m_game->showMainMenu();
     }
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
     else if (answer == KMessageBox::SecondaryAction)
-#else
-    else if (answer == KMessageBox::No)
-#endif
     {
       exit(0);
     }
@@ -1695,27 +1690,15 @@ void GameAutomaton::slotConnectionToClientBroken(KMessageIO *)
     KMessageBox::information(m_game, 
                             i18n("Lost connection to a client.\nFor the moment, you can only save the game and start a new one or quit.\nThis will be improved in a future version."), 
                             i18n("KsirK - Lost connection to client!"));
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
     switch ( KMessageBox::warningTwoActions( m_game,
-#else
-    switch ( KMessageBox::warningYesNo( m_game,
-#endif
                                         i18n("Do want to save your game?"),
                                         QString(),
                                         KStandardGuiItem::save(), KStandardGuiItem::discard()) )
     {
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
     case KMessageBox::PrimaryAction :
-#else
-    case KMessageBox::Yes :
-#endif
       m_game->slotSaveGame();
       break;
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
     case KMessageBox::SecondaryAction :;
-#else
-    case KMessageBox::No :;
-#endif
     default: ;
     }
     if (!m_game->actionNewGame(GameAutomaton::None))
@@ -1874,7 +1857,7 @@ void GameAutomaton::countriesDistribution()
   KMessageParts messageParts;
   messageParts
     << pm
-    << I18N_NOOP("%1: %2 armies to place")
+    << kli18n("%1: %2 armies to place").untranslatedText()
     << nextPlayerName
     <<  QString::number( initialNbArmies - distributedCountriesNumberMap[nextPlayerName]);
   qCDebug(KSIRK_LOG) << "Message parts size= " << messageParts.size();
@@ -2144,7 +2127,7 @@ void GameAutomaton::slotNetworkData(int msgid, const QByteArray &buffer, quint32
       defCountry = this->game()->secondCountry();
       m_game->displayDefenseWindow();
     }
-    messageParts << I18N_NOOP("%1 chooses its defense") << playerName;
+    messageParts << kli18n("%1 chooses its defense").untranslatedText() << playerName;
     m_game->broadcastChangeItem(messageParts, ID_STATUS_MSG2);
     break;
   case ActionDefense:
@@ -2227,7 +2210,7 @@ void GameAutomaton::slotNetworkData(int msgid, const QByteArray &buffer, quint32
   case DecrNbArmies:
     stream >> countryName >> nbArmies;
     m_game->theWorld()->countryNamed(countryName)->decrNbArmies(nbArmies);
-    Q_FALLTHROUGH();
+    [[fallthrough]];
   case StartLocalCurrentAI:
     m_game->startLocalCurrentAI();
     break;
@@ -2291,7 +2274,7 @@ void GameAutomaton::slotNetworkData(int msgid, const QByteArray &buffer, quint32
     }
     break;
   case ShowArmiesToPlace:
-    messageParts << pm << I18N_NOOP("%1: %2 armies to place") << (currentPlayer()-> name()) 
+    messageParts << pm << kli18n("%1: %2 armies to place").untranslatedText() << (currentPlayer()-> name())
       << QString::number(currentPlayer()-> getNbAvailArmies());
     m_game->broadcastChangeItem(messageParts, ID_STATUS_MSG2);
     m_game->showMessage(i18n("Now, place your armies in your countries<br>by clicking in the target countries."));
@@ -2304,7 +2287,7 @@ void GameAutomaton::slotNetworkData(int msgid, const QByteArray &buffer, quint32
     if (isAdmin())
     {
 //       stream >> playerName;
-      messageParts << I18N_NOOP("%1 choose to end recycling; there are now %2 players who want so");
+      messageParts << kli18n("%1 choose to end recycling; there are now %2 players who want so").untranslatedText();
       stream >> nbVotes;
       stream >> playerId;
       playersNames = ((Player*)(findPlayer(playerId)))->name();
@@ -2583,10 +2566,12 @@ void GameAutomaton::slotNetworkData(int msgid, const QByteArray &buffer, quint32
   }
 }
 
+#if HAVE_JABBER_SUPPORT
 void GameAutomaton::askForJabberGames()
 {
   m_game->askForJabberGames();
 }
+#endif
 
 QSvgRenderer& GameAutomaton::rendererFor(const QString& skinName)
 {
@@ -2648,20 +2633,12 @@ void GameAutomaton::actionNextPlayer()
   if ( currentPlayer()->isVirtual()
     || currentPlayer()->isAI()
     || m_currentPlayerPlayed
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
     || (KMessageBox::questionTwoActions (m_game,
-#else
-    || (KMessageBox::questionYesNo (m_game,
-#endif
                                     i18n("%1, you have not played anything this turn.\nDo you really want to lose your turn?",m_currentPlayer),
                                     i18n("Really Next Player?"),
                                     KGuiItem(i18nc("@action:button", "Next Player")),
                                     KStandardGuiItem::cancel())
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
        == KMessageBox::PrimaryAction) )
-#else
-       == KMessageBox::Yes) )
-#endif
   {
     QByteArray buffer;
     QDataStream stream(&buffer, QIODevice::WriteOnly);
